@@ -33,7 +33,7 @@ use std::path::PathBuf;
 
 // Name of environment variable where the prompt could be stored
 #[cfg(feature = "rustyline-support")]
-const PROMPT_STRING: &str = "PROMPT_STRING";
+const PROMPT_COMMAND: &str = "PROMPT_COMMAND";
 
 pub fn search_paths() -> Vec<std::path::PathBuf> {
     use std::env;
@@ -165,7 +165,10 @@ pub fn cli(
     // Store cmd duration in an env var
     context.scope.add_env_var(
         "CMD_DURATION_MS",
-        format!("{}", startup_commands_start_time.elapsed().as_millis()),
+        startup_commands_start_time
+            .elapsed()
+            .as_millis()
+            .to_string(),
     );
 
     if options.perf {
@@ -298,9 +301,9 @@ pub fn cli(
 
         let cwd = context.shell_manager().path();
 
-        // Check if the PROMPT_STRING env variable is set. This env variable
+        // Check if the PROMPT_COMMAND env variable is set. This env variable
         // contains nu code that is used to overwrite the prompt
-        let colored_prompt = match context.scope.get_env(PROMPT_STRING) {
+        let colored_prompt = match context.scope.get_env(PROMPT_COMMAND) {
             Some(env_prompt) => evaluate_prompt_string(&env_prompt, &context, &cwd),
             None => {
                 if let Some(prompt) = &prompt {
@@ -353,7 +356,7 @@ pub fn cli(
         // Store cmd duration in an env var
         context.scope.add_env_var(
             "CMD_DURATION_MS",
-            format!("{}", cmd_start_time.elapsed().as_millis()),
+            cmd_start_time.elapsed().as_millis().to_string(),
         );
 
         match line {
@@ -397,8 +400,7 @@ pub fn cli(
                     .lock()
                     .global_config
                     .as_ref()
-                    .map(|cfg| cfg.var("ctrlc_exit"))
-                    .flatten()
+                    .and_then(|cfg| cfg.var("ctrlc_exit"))
                     .map(|ctrl_c| ctrl_c.is_true())
                     .unwrap_or(false); // default behavior is to allow CTRL-C spamming similar to other shells
 
